@@ -20,15 +20,13 @@
 The global imports import static classes such as parameters and definitions.
 The other classes can be imported from ``tfaip.imports``
 """
+from tfaip.version import __version__
 
-__version__ = "1.2.0"
-
-from tfaip.data.databaseparams import DataBaseParams, DataGeneratorParams
 # IMPORTANT!!!
 # Global imports here must not import tensorflow (it won't crash but it is slow)
 # This leads to unnecessary imports in spawned sub-processes
-from tfaip.data.pipeline.definitions import PipelineMode, Sample, \
-    INPUT_PROCESSOR, GENERAL_PROCESSOR, TARGETS_PROCESSOR
+from tfaip.data.databaseparams import DataBaseParams, DataGeneratorParams
+from tfaip.data.pipeline.definitions import PipelineMode, Sample, INPUT_PROCESSOR, GENERAL_PROCESSOR, TARGETS_PROCESSOR
 from tfaip.device.device_config import DeviceConfigParams
 from tfaip.evaluator.params import EvaluatorParams
 from tfaip.lav.params import LAVParams
