@@ -18,18 +18,14 @@
 """Implementation of LAV"""
 import logging
 import os
-import time
 from abc import ABC
 from queue import Queue
 from threading import Thread
 from typing import TYPE_CHECKING, Type, Dict, List, Callable, Optional, Iterable
-import threading
 
 import tensorflow.keras as keras
-from tensorflow.python.keras.callbacks import Callback, ProgbarLogger
+from tensorflow.python.keras.callbacks import Callback, ProgbarLogger, CallbackList
 from tensorflow.python.keras.engine import data_adapter
-from tensorflow.python.keras.utils.tf_utils import to_numpy_or_python_type
-
 from tfaip import LAVParams, DataGeneratorParams
 from tfaip import Sample
 from tfaip.device.device_config import DeviceConfig, distribute_strategy
@@ -40,6 +36,7 @@ from tfaip.trainer.callbacks.benchmark_callback import BenchmarkCallback, Benchm
 from tfaip.trainer.callbacks.extract_logs import ExtractLogsCallback
 from tfaip.util.file.oshelper import ChDir
 from tfaip.util.shape_utils import to_unbatched_samples
+from tfaip.util.tftyping import sync_to_numpy_or_python_type
 
 if TYPE_CHECKING:
     from tfaip.data.data import DataBase
@@ -73,21 +70,39 @@ class MetricsAccumulator:
             self.running_sum = {k: 0 for k, v in new_values.items()}
             self.running_weight = {k: 0 for k, v in new_values.items()}
 
-        self.running_sum = {k: (self.running_sum[k] + weighted(v, sample_weights.get(k, None))) for k, v in
-                            new_values.items()}
-        self.running_weight = {k: (v + (1 if k not in sample_weights else sample_weights[k])) for k, v in
-                               self.running_weight.items()}
+        self.running_sum = {
+            k: (self.running_sum[k] + weighted(v, sample_weights.get(k, None))) for k, v in new_values.items()
+        }
+        self.running_weight = {
+            k: (v + (1 if k not in sample_weights else sample_weights[k])) for k, v in self.running_weight.items()
+        }
 
     def final(self):
         return {k: v / self.running_weight[k] for k, v in self.running_sum.items()}
 
 
+class InplaceCallbackList(CallbackList):
+    """Callback list that does not create new log objects
+
+    This is required in Tensorflow 2.5.x to support adding and removing of log entries
+    """
+
+    def _process_logs(self, logs, is_batch_hook=False):
+        new_logs = super()._process_logs(logs, is_batch_hook).copy()
+        if logs is not None:
+            logs.clear()
+            logs.update(new_logs)
+            new_logs = logs
+        return new_logs
+
+
 class EvaluationCallback(Callback):
     """Callback to run the post-proc pipeline and call the evaluator
     run post proc pipeline in a separate thread so that it is instantiated only once
     the EvaluationCallback handles writing to post proc queue, reading the post proc data back again
     evaluating the result and writing it to the logs
     """
+
     def __init__(self, evaluator: EvaluatorBase, runnable_data_pipeline):
         super().__init__()
         self._supports_tf_logs = True
@@ -109,14 +124,14 @@ class EvaluationCallback(Callback):
         self.post_proc_runner.start()
 
     def on_test_batch_end(self, batch, logs=None):
-        (inputs, targets, meta), _, outputs = to_numpy_or_python_type(logs['__outputs__'])
+        (inputs, targets, meta), _, outputs = sync_to_numpy_or_python_type(logs["__outputs__"])
 
         samples = to_unbatched_samples(inputs, targets, outputs, meta)
         for sample in samples:
             self.write_queue.put(sample)
 
-        logs.update(self.evaluator.result())  # not up to date, since running asynchron!
-        del logs['__outputs__']
+        # logs.update(self.evaluator.result())  # not up to date, since running asynchron!
+        del logs["__outputs__"]
 
     def on_test_end(self, logs=None):
         assert logs is not None
@@ -142,30 +157,32 @@ class LAV(ABC):
     def params_cls(cls) -> Type[LAVParams]:
         return LAVParams
 
-    def __init__(self,
-                 params: LAVParams,
-                 data_fn: Callable[[], 'DataBase'],
-                 model_fn: Callable[[], 'ModelBase'],
-                 evaluator_fn: Callable[[], EvaluatorBase],
-                 ):
+    def __init__(
+        self,
+        params: LAVParams,
+        data_fn: Callable[[], "DataBase"],
+        model_fn: Callable[[], "ModelBase"],
+        evaluator_fn: Callable[[], EvaluatorBase],
+    ):
         assert params.model_path
         self._params = params
         self._data_fn = data_fn
         self._model_fn = model_fn
         self._evaluator_fn = evaluator_fn
         self.device_config = DeviceConfig(self._params.device)
-        self._data: Optional['DataBase'] = None
-        self._model: Optional['ModelBase'] = None
+        self._data: Optional["DataBase"] = None
+        self._model: Optional["ModelBase"] = None
         self.benchmark_results = BenchmarkResults()
 
     @distribute_strategy
-    def run(self,
-            generator_params: Iterable[DataGeneratorParams],
-            keras_model: keras.Model = None,
-            run_eagerly=False,
-            callbacks: List[LAVCallback] = None,
-            return_tensorboard_outputs=False,
-            ) -> Iterable[Dict[str, float]]:
+    def run(
+        self,
+        generator_params: Iterable[DataGeneratorParams],
+        keras_model: keras.Model = None,
+        run_eagerly=False,
+        callbacks: List[LAVCallback] = None,
+        return_tensorboard_outputs=False,
+    ) -> Iterable[Dict[str, float]]:
         callbacks = callbacks or []
         with ChDir(os.path.join(self._params.model_path)):
             # resources are located in parent dir
@@ -177,12 +194,15 @@ class LAV(ABC):
             cb.lav, cb.data, cb.model = self, self._data, model
 
         if run_eagerly:
-            logger.warning('Running in eager mode. Use this only for debugging, since the graph of the saved model '
-                           'might get changed due to "reconstruction" of the graph')
+            logger.warning(
+                "Running in eager mode. Use this only for debugging, since the graph of the saved model "
+                'might get changed due to "reconstruction" of the graph'
+            )
 
         if not keras_model:
-            keras_model = keras.models.load_model(os.path.join(self._params.model_path, 'serve'),
-                                                  compile=False, custom_objects=model.all_custom_objects())
+            keras_model = keras.models.load_model(
+                os.path.join(self._params.model_path, "serve"), compile=False, custom_objects=model.all_custom_objects()
+            )
 
         # create a new keras model that uses the inputs and outputs of the loaded model but adds the targets of the
         # dataset. Then create the metrics as output of the new model
@@ -200,15 +220,16 @@ class LAV(ABC):
             def test_step(self, data):
                 data = data_adapter.expand_1d(data)
                 x, y, sample_weight = data_adapter.unpack_x_y_sample_weight(data)
+                inputs, _, meta = x
+
+                y_pred, pre_proc_targets = self(x, training=False)
 
-                y_pred = self(x, training=False)
                 # Updates stateful loss metrics.
-                self.compiled_loss(
-                    y, y_pred, sample_weight, regularization_losses=self.losses)
+                self.compiled_loss(y, y_pred, sample_weight, regularization_losses=self.losses)
 
                 self.compiled_metrics.update_state(y, y_pred, sample_weight)
                 logs = {m.name: m.result() for m in self.metrics}
-                logs['__outputs__'] = (x, y, y_pred)
+                logs["__outputs__"] = ((inputs, pre_proc_targets, meta), y, y_pred)
                 return logs
 
             def get_config(self):
@@ -227,16 +248,15 @@ class LAV(ABC):
             val_data = self._data.create_pipeline(self._params.pipeline, params)
             with evaluator:
                 with val_data as rd:
-                    extract_logs_callback = ExtractLogsCallback(test_prefix='')
-                    benchmark_callback = BenchmarkCallback()
-                    eval_callbacks = [EvaluationCallback(evaluator, rd),
-                                      extract_logs_callback, benchmark_callback]
+                    extract_logs_callback = ExtractLogsCallback(test_prefix="")
+                    benchmark_callback = BenchmarkCallback(extract_logs_callback)
+                    eval_callbacks = [EvaluationCallback(evaluator, rd), extract_logs_callback, benchmark_callback]
                     if not self._params.silent:
-                        eval_callbacks.append(ProgbarLogger(count_mode='steps'))
+                        eval_callbacks.append(ProgbarLogger(count_mode="steps"))
 
                     r = lav_model.evaluate(
                         rd.input_dataset().map(regroup),
-                        callbacks=eval_callbacks,
+                        callbacks=InplaceCallbackList(eval_callbacks, model=lav_model),
                         return_dict=True,
                         verbose=0 if self._params.silent else 1,
                     )
@@ -247,6 +267,9 @@ class LAV(ABC):
                     self._on_lav_end(params, r)
                     for cb in callbacks:
                         cb.on_lav_end(params, r)
+
+                    if not self._params.silent:
+                        logger.info("LAV results: \n" + "\n    ".join([f"{k} = {v}" for k, v in r.items()]))
                     yield r
 
     def _on_sample_end(self, data_generator_params: DataGeneratorParams, sample: Sample):
