@@ -18,14 +18,11 @@
 """Definition of the PredictorBase"""
 import logging
 from abc import ABC, abstractmethod
-from dataclasses import dataclass
 from typing import TYPE_CHECKING, Type, Iterable, Union, Optional, Any
 
-import prettytable
 from tensorflow import keras
 import tensorflow as tf
 from tensorflow.python.keras.engine import data_adapter
-from tensorflow.python.keras.utils import tf_utils
 
 from tfaip.data.databaseparams import DataGeneratorParams, DataPipelineParams
 from tfaip import PipelineMode, Sample
@@ -33,10 +30,12 @@ from tfaip import PredictorParams
 from tfaip.data.pipeline.datagenerator import DataGenerator
 from tfaip.data.pipeline.datapipeline import DataPipeline
 from tfaip.device.device_config import DeviceConfig, distribute_strategy
+from tfaip.predict.raw_predictor import RawPredictor
 from tfaip.trainer.callbacks.benchmark_callback import BenchmarkResults
 from tfaip.util.multiprocessing.parallelmap import tqdm_wrapper
 from tfaip.util.profiling import MeasureTime
 from tfaip.util.tfaipargparse import post_init
+from tfaip.util.tftyping import sync_to_numpy_or_python_type
 
 if TYPE_CHECKING:
     from tfaip.data.data import DataBase
@@ -72,7 +71,7 @@ class PredictorBase(ABC):
     def params_cls(cls) -> Type[PredictorParams]:
         return PredictorParams
 
-    def __init__(self, params: PredictorParams, data: 'DataBase'):
+    def __init__(self, params: PredictorParams, data: "DataBase"):
         post_init(params)
         self._params = params
         self._params.pipeline.mode = PipelineMode.PREDICTION
@@ -97,6 +96,27 @@ class PredictorBase(ABC):
 
         return model
 
+    def raw(self) -> RawPredictor:
+        """Create a raw predictor from this predictor that allows to asynchronly predict raw samples.
+
+        Usage:
+
+        Either call
+
+        with predictor.raw() as raw_pred:
+            raw_pred(sample1)
+            raw_pred(sample2)
+            ...
+
+        or
+
+        raw_pred = predictor.raw().__enter__()
+        raw_pred(sample1)
+        raw_pred(sample2)
+
+        """
+        return RawPredictor(self)
+
     def predict(self, params: DataGeneratorParams) -> Iterable[Sample]:
         """
         Predict a DataGenerator based on its params.
@@ -136,6 +156,7 @@ class PredictorBase(ABC):
             - predict_pipeline
             - predict_dataset
             - predict
+            - raw
         """
         if size is None:
             # Automatically compute the size (number of samples)
@@ -143,7 +164,8 @@ class PredictorBase(ABC):
                 size = len(inputs)
             except TypeError:
                 logger.warning(
-                    'Size not specified. Converting inputs to list to obtain size. Or implement size on inputs')
+                    "Size not specified. Converting inputs to list to obtain size. Or implement size on inputs"
+                )
                 inputs = list(inputs)
             size = len(inputs)
 
@@ -160,10 +182,11 @@ class PredictorBase(ABC):
                 return RawGenerator(mode=self.mode, params=self.generator_params)
 
         pipeline = RawInputsPipeline(
-            DataPipelineParams(mode=PipelineMode.PREDICTION),
+            self.params.pipeline,
             self._data,
             DataGeneratorParams(),
         )
+
         return self.predict_pipeline(pipeline)
 
     def predict_pipeline(self, pipeline: DataPipeline) -> Iterable[Sample]:
@@ -183,10 +206,10 @@ class PredictorBase(ABC):
         """
         with pipeline as rd:
             for sample in tqdm_wrapper(
-                    rd.process_output(self.predict_dataset(rd.input_dataset())),
-                    progress_bar=self._params.progress_bar,
-                    desc='Prediction',
-                    total=len(rd),
+                rd.process_output(self.predict_dataset(rd.input_dataset())),
+                progress_bar=self._params.progress_bar,
+                desc="Prediction",
+                total=len(rd),
             ):
                 if not self._params.silent:
                     self._print_prediction(sample, logger.info)
@@ -210,7 +233,7 @@ class PredictorBase(ABC):
             - predict_raw
         """
         if self._keras_model is None:
-            raise ValueError('No model set. Call predictor.set_model(model)')
+            raise ValueError("No model set. Call predictor.set_model(model)")
 
         keras_model = self._keras_model
 
@@ -235,9 +258,9 @@ class PredictorBase(ABC):
         wrapped_model.compile(run_eagerly=True)
 
         if self._params.include_targets:
-            dataset = dataset.map(lambda i, t, m: ((i, t, m), ))
+            dataset = dataset.map(lambda i, t, m: ((i, t, m),))
         else:
-            dataset = dataset.map(lambda i, m: ((i, m), ))
+            dataset = dataset.map(lambda i, m: ((i, m),))
 
         with MeasureTime() as total_time:
             # The following code is copied from keras.model.Model.predict
@@ -254,16 +277,16 @@ class PredictorBase(ABC):
 
                                 # If targets are included, the return value differs
                                 if self._params.include_targets:
-                                    inputs, targets, outputs, meta = tf_utils.to_numpy_or_python_type(r)
+                                    inputs, targets, outputs, meta = sync_to_numpy_or_python_type(r)
                                 else:
-                                    inputs, outputs, meta = tf_utils.to_numpy_or_python_type(r)
+                                    inputs, outputs, meta = sync_to_numpy_or_python_type(r)
                                     targets = {}  # No targets in normal prediction
 
                                 # split into single samples
                                 try:
                                     batch_size = tf.nest.flatten(inputs)[0].shape[0]
                                 except StopIteration as e:
-                                    raise ValueError(f'Empty inputs {inputs}. This should never occur!') from e
+                                    raise ValueError(f"Empty inputs {inputs}. This should never occur!") from e
                                 for sample in self._unwrap_batch(inputs, targets, outputs, meta):
                                     self._on_sample_end(sample)
                                     yield sample
